from enum import Enum


class LanguageCode(str, Enum):
    ar_xa = 'ar-xa'
    cs_cz = 'cs-cz'
    cy_cy = 'cy-cy'
    cy_gb = 'cy-gb'
    da_dk = 'da-dk'
    de_de = 'de-de'
    el_gr = 'el-gr'
    en_au = 'en-au'
    en_gb = 'en-gb'
    en_in = 'en-in'
    en_us = 'en-us'
    es_es = 'es-es'
    es_mx = 'es-mx'
    es_us = 'es-us'
    fi_fi = 'fi-fi'
    fil_ph = 'fil-ph'
    fr_ca = 'fr-ca'
    fr_fr = 'fr-fr'
    hi_in = 'hi-in'
    hu_hu = 'hu-hu'
    id_id = 'id-id'
    is_is = 'is-is'
    it_it = 'it-it'
    ja_jp = 'ja-jp'
    ko_kr = 'ko-kr'
    nb_no = 'nb-no'
    nl_nl = 'nl-nl'
    pl_pl = 'pl-pl'
    pt_br = 'pt-br'
    pt_pt = 'pt-pt'
    ro_ro = 'ro-ro'
    ru_ru = 'ru-ru'
    sv_se = 'sv-se'
    th_th = 'th-th'
    tr_tr = 'tr-tr'
    vi_vn = 'vi-vn'
    yue_cn = 'yue-cn'
    zh_cn = 'zh-cn'
    zh_tw = 'zh-tw'


class Psd2LanguageCode(str, Enum):
    en_gb = 'en-gb'
    bg_bg = 'bg-bg'
    cs_cz = 'cs-cz'
    da_dk = 'da-dk'
    de_de = 'de-de'
    ee_et = 'ee-et'
    el_gr = 'el-gr'
    es_es = 'es-es'
    fi_fi = 'fi-fi'
    fr_fr = 'fr-fr'
    ga_ie = 'ga-ie'
    hu_hu = 'hu-hu'
    it_it = 'it-it'
    lv_lv = 'lv-lv'
    lt_lt = 'lt-lt'
    mt_mt = 'mt-mt'
    nl_nl = 'nl-nl'
    pl_pl = 'pl-pl'
    sk_sk = 'sk-sk'
    sl_si = 'sl-si'
    sv_se = 'sv-se'
